#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-poj6iPyXPPFpTZ1Eg0uxL
key:                  coinbase-pro-0.9.3.2-poj6iPyXPPFpTZ1Eg0uxL
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  28afc7cb5f1c3dc5ebf8431005de7427
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-poj6iPyXPPFpTZ1Eg0uxL
depends:
    HsOpenSSL-0.11.7.9-IwZsOB6JczEEc8pRVGHtFE
    aeson-2.2.1.0-B4RqQZAnAt5HkJbmyrGfNz
    aeson-casing-0.2.0.0-GKabeydPG5OAiVwgEp75tp
    async-2.2.5-Jzg6PXAbUPTGsNolvwhTll base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-FSHArbPHDjH50eqXmOoKSp exceptions-0.10.7
    http-api-data-0.6.1-Ap70tYePO94JL43AkaQvXa
    http-client-0.7.19-86q5uP36PXVA1VU7ir8jG7
    http-client-tls-0.3.6.4-Jmopvhh6XJdDm7pjT39Fiq
    http-streams-0.8.9.9-J1jzyRGLdJYIVaNC6683iP
    http-types-0.12.4-27GAurifKVpxMGrjggVXj
    io-streams-1.5.2.2-JCCiFuN3BMoB0VTxTiM7fE
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-75tKhCALOXaIm7EtXFkhVT
    servant-0.20.3.0-8NKsw0NIMnvKqdi9yg5aPo
    servant-client-0.20.3.0-9LsIx9eHfMWLEj6xlbnHXz
    servant-client-core-0.20.3.0-3xa2jFb5FcwIZgQXijDTs
    tasty-1.5.2-6YVZGV3DoLa3No8MaV4iM1
    tasty-hunit-0.10.2-9y5vdIEOBAeFNi5SypX4om text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-Cz8yw2sSRFaLvCYziOjvf4
    unordered-containers-0.2.20.1-C4c13QuwLgs7TJHWi6VHCN
    uuid-1.3.16-7dtMJHW7vNkAahr5eLmavU
    vector-0.13.2.0-AKpLem9JWa2IilUORfhwQi
    websockets-0.12.7.3-AzW7NDUzhNw2biYvHK9hSz
    wuss-2.0.1.6-5Y45nsUqqp58y9ejcerxuB

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

